/**
 * This is a simple class that does some data processing.
 *
 * @author Vanessa Grose
 * @date August 15, 2005
 * 
 * @title SimpleProgram -- This test does some simple File I/O
 * @name SimpleProgram
 * @source SimpleProgram.java
*/
 

import java.io.*;
import java.util.*;
import java.util.zip.*;
import java.net.*;
 
public class SimpleProgram {
	
   private BufferedReader in;

   private BufferedReader getDefaultReaderFromJar() {
	
	try {

		ZipFile zip = new ZipFile( "SimpleProgram.jar" );
		ZipEntry ent = new ZipEntry( zip.getEntry( "ibm.html" ));
		BufferedReader in = new BufferedReader( new InputStreamReader( zip.getInputStream(ent) ));
		return in;
	}
	catch( IOException ex ) {
		ex.printStackTrace();
	}
	return null;
   }
 
   public static void main(String args[]) {

	SimpleProgram sp = new SimpleProgram();
	
	if( args.length > 0 ) {
		try {
			// Try to process the file input argument
			URL toRead = new URL( args[0] );
			sp.in = new BufferedReader( new InputStreamReader( toRead.openStream()) );

		}
		catch( IOException ex1 ) {
		
			System.out.println( "Unable to process " + args[0] );
			System.out.println( "Defaulting to http://www.ibm.com" );
			sp.in = sp.getDefaultReaderFromJar();
		}
	}
	else {
		System.out.println( "No argument specified" );
		System.out.println( "Defaulting to http://www.ibm.com" );	
		sp.in = sp.getDefaultReaderFromJar();
	}

	try {

		HashMap hash = new HashMap();

		// Run through the file
		while( sp.in.ready() ) {
			String line = new String( sp.in.readLine() );

			// We're going to cycle through the file and create a hash containing the
			// count of all of the characters that the file contains

			int length = line.length();
			for( int i = 0; i < length; i++ ) {
				char c = line.charAt(i);
				Character key = new Character( c );
				if( hash.containsKey( key ) ) {
					// Grab current value, update it, and put it back in
					Integer valueOut = (Integer)hash.get( key ); 
					int num = valueOut.intValue();
					num++;
					Integer valueIn = new Integer( num );
					hash.put( key, valueIn );
				}
				else {
					Integer valueIn = new Integer( 1 );
					hash.put( key, valueIn );
				}
			}	
		}

		// Now hash contains all of the characters in the file along with a count of how
		// many times each character occurs.

		Integer maxValue = new Integer( 0 );
		Character maxKey = new Character( ' ' );

		Set keys = hash.keySet();
		Iterator it = keys.iterator();

		if( it.hasNext() ) {
			maxKey = (Character)it.next();
			maxValue = (Integer)hash.get( maxKey );
		}
		else {
			System.out.println( "No characters available to check, ending program." );
			System.exit( 0 );
		}

		while( it.hasNext() ) {
			Character posKey = (Character)it.next();
			Integer posValue = (Integer)hash.get( posKey );
			if( posValue.intValue() > maxValue.intValue() ) {
				maxKey = posKey;
				maxValue = posValue;
			}
		}
		System.out.println( "The most common character in the file is: " + maxKey );
		System.out.println( "The number of occurences of " + maxKey + " is: " + maxValue );	
	}
	catch( MalformedURLException mue ) {
		mue.printStackTrace();
	}
	catch( IOException ioe ) {
		ioe.printStackTrace();
	}

   }

}